#
# spec file for package python-smart-open
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-smart-open
Version:        6.4.0
Release:        1.1
Summary:        Python utils for streaming large files
License:        MIT
URL:            https://github.com/RaRe-Technologies/smart_open
Source:         https://github.com/RaRe-Technologies/smart_open/archive/refs/tags/v%{version}.tar.gz#/smart_open-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-azure-common
Requires:       python-azure-core
Requires:       python-azure-storage-blob
Requires:       python-boto3
Requires:       python-google-cloud-storage
Requires:       python-requests
Suggests:       python-paramiko
BuildArch:      noarch
# see https://github.com/RaRe-Technologies/smart_open/issues/784
BuildRequires:  %{python_module urllib3 < 2}
Requires:       python-urllib3 < 2
# SECTION test requirements
BuildRequires:  %{python_module azure-common}
BuildRequires:  %{python_module azure-core}
BuildRequires:  %{python_module azure-storage-blob}
BuildRequires:  %{python_module boto3}
BuildRequires:  %{python_module google-cloud-storage}
BuildRequires:  %{python_module moto >= 1.3.4}
BuildRequires:  %{python_module moto-server}
BuildRequires:  %{python_module paramiko}
BuildRequires:  %{python_module pytest-rerunfailures}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module responses}
# /SECTION
%python_subpackages

%description
Python utils for streaming large files.
Includes support for S3, HDFS, gzip, bz2, etc.

%prep
%setup -q -n smart_open-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
moto_server -p5000 2>/dev/null &
export SO_ENABLE_MOTO_SERVER=1
%pytest -rs smart_open/

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/smart[-_]open*/

%changelog
* Thu Oct 12 2023 Ondřej Súkup <mimi.vx@gmail.com>
- Update to 6.4.0
- force require urllib3 < 2 because of https://github.com/RaRe-Technologies/smart_open/issues/784
  * Ignore S3 seeks to the current position (PR #782, @beck3905
  * Set binary mode prior to FTP write ()PR #781, @beck3905)
  * Improve S3 URI Parsing for URIs with "@", "/", and ":" (PR #776, @rileypeterson)
  * Add python 3.11 to setup.py (PR #775, @tooptoop4)
  * Fix retrieving empty but existing object from S3 (PR #771, @Darkheir)
  * Avoid overfilling buffer when reading from Azure (PR #767, @ronreiter)
  * Add required import for example to work (PR #756, @jensenbox)
* Fri Jan  6 2023 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 6.3.0
  * Refactor Google Cloud Storage to use blob.open (ddelange, #744)
  * Add FTP/FTPS support (#33) (RachitSharma2001, #739)
  * Bring back compression_wrapper(filename) + use case-insensitive extension matching (piskvorky, #737)
  * Fix avoidable S3 race condition (#693) (RachitSharma2001, #735)
  * setup.py: Remove pathlib2 (jayvdb, #733)
  * Add flake8 config globally (cadnce, #732)
  * Added buffer_size parameter to http module (mullenkamp, #730)
  * Added documentation to support GCS anonymously (cadnce, #728)
  * Reconnect inactive sftp clients automatically (Kache, #719)
* Sat Oct 15 2022 John Vandenberg <jayvdb@gmail.com>
- Update to v6.2.0
* Fri Sep 18 2020 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
- Update to v2.2.1
* Wed Dec 25 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.9.0
